@@ -11,3 +11,8 @@
 #include <arpa/inet.h>
 #include "dv_echo.h"
 
+void	audio_msg(char caller[], char repeater[])
+{
+
+	printf ("debug audio message %8.8s %8.8s\n", caller, repeater);
+}
